aboutsummaryrefslogtreecommitdiff
path: root/src/util
diff options
context:
space:
mode:
authorMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-03-09 14:53:36 +0100
committerMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-03-09 15:05:11 +0100
commitfaf3f12424fa8558e65fa3f1dd3aa1d0eea8604e (patch)
treed0a29883cfc45ba7a2e56234938083dda597d24a /src/util
parent8d12127a9c19cb218d661a88ab9b6871c9d853b9 (diff)
refactor: Replace GetTimeMicros by SystemClock
Diffstat (limited to 'src/util')
-rw-r--r--src/util/time.cpp5
-rw-r--r--src/util/time.h10
2 files changed, 5 insertions, 10 deletions
diff --git a/src/util/time.cpp b/src/util/time.cpp
index 58200c83fc..fb9bc34931 100644
--- a/src/util/time.cpp
+++ b/src/util/time.cpp
@@ -107,11 +107,6 @@ int64_t GetTimeMillis()
return int64_t{GetSystemTime<std::chrono::milliseconds>().count()};
}
-int64_t GetTimeMicros()
-{
- return int64_t{GetSystemTime<std::chrono::microseconds>().count()};
-}
-
int64_t GetTime() { return GetTime<std::chrono::seconds>().count(); }
std::string FormatISO8601DateTime(int64_t nTime) {
diff --git a/src/util/time.h b/src/util/time.h
index fcf85c1e03..8c6baeb12a 100644
--- a/src/util/time.h
+++ b/src/util/time.h
@@ -29,6 +29,8 @@ using SteadySeconds = std::chrono::time_point<std::chrono::steady_clock, std::ch
using SteadyMilliseconds = std::chrono::time_point<std::chrono::steady_clock, std::chrono::milliseconds>;
using SteadyMicroseconds = std::chrono::time_point<std::chrono::steady_clock, std::chrono::microseconds>;
+using SystemClock = std::chrono::system_clock;
+
void UninterruptibleSleep(const std::chrono::microseconds& n);
/**
@@ -63,16 +65,14 @@ using MillisecondsDouble = std::chrono::duration<double, std::chrono::millisecon
* DEPRECATED
* Use either ClockType::now() or Now<TimePointType>() if a cast is needed.
* ClockType is
* - std::chrono::steady_clock for steady time
* - std::chrono::system_clock for system time
* - NodeClock for mockable system time
*/
int64_t GetTime();
/** Returns the system time (not mockable) */
int64_t GetTimeMillis();
-/** Returns the system time (not mockable) */
-int64_t GetTimeMicros();
/**
* DEPRECATED
@@ -63,16 +65,14 @@ using MillisecondsDouble = std::chrono::duration<double, std::chrono::millisecon
* Use either ClockType::now() or Now<TimePointType>() if a cast is needed.
* ClockType is
- * - std::chrono::steady_clock for steady time
- * - std::chrono::system_clock for system time
- * - NodeClock for mockable system time
+ * - SteadyClock/std::chrono::steady_clock for steady time
+ * - SystemClock/std::chrono::system_clock for system time
+ * - NodeClock for mockable system time
*/
int64_t GetTime();